Summary:        Hybrid image/package system
Name:           rpm-ostree
Version:        2024.4
Release:        1%{?dist}
License:        LGPLv2+
URL:            https://github.com/coreos/rpm-ostree
# You can get tar via "cd packaging && make -f Makefile.dist-packaging dist-snapshot"
Source0:        https://github.com/coreos/rpm-ostree/releases/download/v%{version}/rpm-ostree-%{version}.tar.xz
Source1:        autofiles.py

Patch0: 0001-cliwrap-rpm-mark-eval-E-as-safe.patch
# fix CVE-2024-2905 ;https://github.com/coreos/rpm-ostree/pull/4911
Patch1: 0001-passwd-create-etc-g-shadow-with-mode-0.patch
Patch2: 0002-unit-chmod-etc-g-shadow-to-0000.patch
Patch3: 0003-shadow-Adjust-all-deployments.patch

Patch4: 0001-add-loongarch64-support-not-upstream-modified-files.patch

BuildRequires:  make cargo rust libxslt docbook-style-xsl
BuildRequires:  autoconf automake libtool git
BuildRequires:  chrpath libcap-devel libattr-devel cmake
BuildRequires:  pkgconfig(ostree-1) pkgconfig(polkit-gobject-1) pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(rpm) pkgconfig(libarchive) pkgconfig(libsystemd) pkgconfig(librepo)
BuildRequires:  pkgconfig(libcurl) pkgconfig(expat) pkgconfig(check) pkgconfig(libsolv)
BuildRequires:  /usr/bin/g-ir-scanner
BuildRequires:  python3-devel

# libdnf build deps
BuildRequires:  cmake gcc gcc-c++ libsolv-devel rpm-devel gettext gpgme-devel
BuildRequires:  pkgconfig(librepo) pkgconfig(check) pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(sqlite3) pkgconfig(json-c) pkgconfig(cppunit)
BuildRequires:  pkgconfig(modulemd-2.0) pkgconfig(smartcols) pkgconfig(zck)

Requires:       libmodulemd libsolv librepo
Requires:       %{name}-libs = %{version}-%{release}
Requires:       ostree bubblewrap fuse

Recommends:     skopeo

ExclusiveArch:  x86_64 aarch64 ppc64le loongarch64

%description
This package provides a hybrid image/package system.
It supports "composing" packages on a build server into an OSTree repository,
which can then be replicated by client systems with atomic upgrades.
Additionally, unlike many "pure" image systems, with rpm-ostree
each client system can layer on additional packages, providing
a "best of both worlds" approach.

%package libs
Summary: Shared library for rpm-ostree

%description libs
This package includes the shared library for %{name}.

%package devel
Summary: Development headers for %{name}
Requires: %{name}-libs = %{version}-%{release}

%description devel
This package includes the header files for %{name}-libs.

%prep
%autosetup -Sgit -n %{name}-%{version}
cp %{SOURCE1} .

# do not support gtk-doc
sed -i 's/documentation" ON/documentation" OFF/g' libdnf/CMakeLists.txt

%build
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules

%make_build

%install
%make_install INSTALL="install -p -c"
find %{buildroot} -name '*.la' -delete

python3 autofiles.py > files \
  '%{_bindir}/*' \
  '%{_libdir}/%{name}' \
  '%{_mandir}/man*/*' \
  '%{_datadir}/dbus-1/system.d/*' \
  '%{_sysconfdir}/rpm-ostreed.conf' \
  '%{_prefix}/lib/systemd/system/*' \
  '%{_libexecdir}/rpm-ostree*' \
  '%{_libexecdir}/libostree/ext/*' \
  '%{_datadir}/polkit-1/actions/*.policy' \
  '%{_datadir}/dbus-1/system-services/*' \
  '%{_datadir}/bash-completion/completions/*'

python3 autofiles.py > files.lib \
  '%{_libdir}/*.so.*' \
  '%{_libdir}/girepository-1.0/*.typelib'

python3 autofiles.py > files.devel \
  '%{_libdir}/lib*.so' \
  '%{_includedir}/*' \
  '%{_datadir}/dbus-1/interfaces/org.projectatomic.rpmostree1.xml' \
  '%{_libdir}/pkgconfig/*' \
  '%{_datadir}/gtk-doc/html/*' \
  '%{_datadir}/gir-1.0/*-1.0.gir'

%post
# Only enable on rpm-ostree based systems and manually force unit enablement to
# explicitly ignore presets for this security fix
if [ -e /run/ostree-booted ]; then
    ln -snf /usr/lib/systemd/system/rpm-ostree-fix-shadow-mode.service  /usr/lib/systemd/system/multi-user.target.wants/
fi

%preun
%systemd_preun rpm-ostree-countme.timer

%postun
%systemd_postun_with_restart rpm-ostree-countme.timer

%files -f files
%license COPYING.GPL COPYING.LGPL
%doc LICENSE README.md

%files libs -f files.lib

%files devel -f files.devel

%changelog
* Tue Mar 25 2025 Doris Chao <doriscchao@tencent.com> - 2024.4-1
- [Type] security
- [DESC] Upgrade to version 2024.4 to fix CVE-2023-26964(h2). 
- Backport https://github.com/coreos/rpm-ostree/security/advisories/GHSA-2m76-cwhg-7wv6, CVE-2024-2905.
- Backport https://github.com/coreos/rpm-ostree/commit/fe586621e5014d14f92b913338171a02ed29e6cc

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2023.2-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2023.2-5
- Rebuilt for loongarch release

* Mon Mar 18 2024 doupengda <doupengda@loongson.cn> - 2023.2-4
- add support for loongarch64, from @huajingyun

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2023.2-3
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 18 2023 Wang Guodong <gordonwwang@tencent.com> - 2023.2-2
- Rebuilt for rust 1.69.0

* Wed Jul 12 2023 cunshunxia <cunshunxia@tencent.com> - 2023.2-1
- upgrade to 2023.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.13-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.13-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 8 2022 Wang Guodong <gordonwwang@tencent.com> - 2022.13-2
- rebuild for cargo-1.64.0(rust-1.64.0).

* Thu Nov 17 2022 Shuo Wang <abushwang@tencent.com> - 2022.13-1
- initial build
